@@ -2,8 +2,6 @@ package Catalyst::Helper::View::Mason;
 
 use strict;
 
-our $VERSION = '0.06';
-
 =head1 NAME
 
 Catalyst::Helper::View::Mason - Helper for Mason Views
@@ -24,17 +22,40 @@ Helper for Mason Views.
 
 sub mk_compclass {
     my ( $self, $helper ) = @_;
-    my $file  = $helper->{file};
-    my $class = $helper->{class};
-    $helper->mk_file( $file, <<"EOF");
-package $class;
+    my $file = $helper->{file};
+    $helper->render_file( 'compclass', $file );
+}
+
+=head1 SEE ALSO
+
+L<Catalyst::Manual>, L<Catalyst::Test>, L<Catalyst::Request>,
+L<Catalyst::Response>, L<Catalyst::Helper>
+
+=head1 AUTHOR
+
+Andres Kievsky
+Sebastian Riedel, C<sri@oook.de>
+
+=head1 LICENSE
+
+This library is free software . You can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut
+
+1;
+
+__DATA__
+
+__compclass__
+package [% class %];
 
 use strict;
 use base 'Catalyst::View::Mason';
 
 =head1 NAME
 
-$class - Mason View Component
+[% class %] - Mason View Component
 
 =head1 SYNOPSIS
 
@@ -56,27 +77,3 @@ the same terms as perl itself.
 =cut
 
 1;
-EOF
-}
-
-=head1 SEE ALSO
-
-L<Catalyst::Manual>, L<Catalyst::Test>, L<Catalyst::Request>,
-L<Catalyst::Response>, L<Catalyst::Helper>
-
-=head1 AUTHOR
-
-Andres Kievsky, C<ank@cpan.org>
-
-based on the TT View Helper from:
-
-Sebastian Riedel, C<sri@oook.de>
-
-=head1 LICENSE
-
-This library is free software . You can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut
-
-1;
